==> ejc-businessplan-impl-3.0.0-20220321.111257-20-sources.jar: com/ejianc/business/utils/DateUtils.java <==
package com.ejianc.business.utils;

import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.Date;

public class DateUtils {
    public static String dateSimple(Date date){
        SimpleDateFormat sDateFormat=new SimpleDateFormat("yyyy-MM-dd");
        String formatDate = sDateFormat.format(date);
        return formatDate;

    }

    public static String dateSimple2(Date date){
        SimpleDateFormat sDateFormat=new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
        String formatDate = sDateFormat.format(date);
        return formatDate;

    }

    public static Date Date(String days) throws ParseException {
        SimpleDateFormat sDateFormat=new SimpleDateFormat("yyyy-MM-dd");
        String dateStr = ExcelDoubleToDate(days);
        Date date=sDateFormat.parse(dateStr);
        return date;
    }
    public static String ExcelDoubleToDate(String strDate) {
        if(strDate.length() == 5){
            try {
                SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd");
                Date tDate = DoubleToDate(Double.parseDouble(strDate));
                return sdf.format(tDate);
            }catch (Exception e){
                e.printStackTrace();
                return strDate;
            }
        }
        return strDate;
    }

    //解析Excel日期格式
    public static Date DoubleToDate(Double dVal) {
        Date tDate = new Date();
        long localOffset = tDate.getTimezoneOffset() * 60000; //系统时区偏移 1900/1/1 到 1970/1/1 的 25569 天
        tDate.setTime((long) ((dVal - 25569) * 24 * 3600 * 1000 + localOffset));

        return tDate;
    }

}

==> ejc-businessplan-impl-3.0.0-20220509.094648-60-sources.jar: com/ejianc/business/utils/DateUtils.java <==
package com.ejianc.business.utils;

import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.Date;

public class DateUtils {
    public static String dateSimple(Date date){
        SimpleDateFormat sDateFormat=new SimpleDateFormat("yyyy/MM/dd");
        String formatDate = sDateFormat.format(date);
        return formatDate;

    }

    public static String dateSimple2(Date date){
        SimpleDateFormat sDateFormat=new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
        String formatDate = sDateFormat.format(date);
        return formatDate;

    }

    public static Date Date(String days) throws ParseException {
        SimpleDateFormat sDateFormat=new SimpleDateFormat("yyyy/MM/dd");
        String dateStr = ExcelDoubleToDate(days);
        Date date=sDateFormat.parse(dateStr);
        return date;
    }
    public static String ExcelDoubleToDate(String strDate) {
        if(strDate.length() == 5){
            try {
                SimpleDateFormat sdf = new SimpleDateFormat("yyyy/MM/dd");
                Date tDate = DoubleToDate(Double.parseDouble(strDate));
                return sdf.format(tDate);
            }catch (Exception e){
                e.printStackTrace();
                return strDate;
            }
        }
        return strDate;
    }

    //解析Excel日期格式
    public static Date DoubleToDate(Double dVal) {
        Date tDate = new Date();
        long localOffset = tDate.getTimezoneOffset() * 60000; //系统时区偏移 1900/1/1 到 1970/1/1 的 25569 天
        tDate.setTime((long) ((dVal - 25569) * 24 * 3600 * 1000 + localOffset));

        return tDate;
    }

}
